@@ -29,12 +29,12 @@ impl AudioNode for WhiteNoiseNode {
     }
 
     // source nodes take no input
-    fn number_of_inputs(&self) -> u32 {
+    fn number_of_inputs(&self) -> usize {
         0
     }
 
     // emit a single output
-    fn number_of_outputs(&self) -> u32 {
+    fn number_of_outputs(&self) -> usize {
         1
     }
 }
@@ -50,9 +50,7 @@ impl WhiteNoiseNode {
                 default_value: 1.,
                 automation_rate: AutomationRate::A,
             };
-            let (param, proc) = context
-                .base()
-                .create_audio_param(param_opts, registration.id());
+            let (param, proc) = context.base().create_audio_param(param_opts, &registration);
 
             // setup the processor, this will run in the render thread
             let render = WhiteNoiseProcessor { amplitude: proc };
