@@ -97,11 +97,11 @@ impl AudioNode for AudioBufferSourceNode {
         &self.channel_config
     }
 
-    fn number_of_inputs(&self) -> u32 {
+    fn number_of_inputs(&self) -> usize {
         0
     }
 
-    fn number_of_outputs(&self) -> u32 {
+    fn number_of_outputs(&self) -> usize {
         1
     }
 }
@@ -154,7 +154,7 @@ impl AudioBufferSourceNode {
             };
             let (d_param, d_proc) = context
                 .base()
-                .create_audio_param(detune_param_options, registration.id());
+                .create_audio_param(detune_param_options, &registration);
 
             d_param.set_value(detune);
 
@@ -166,7 +166,7 @@ impl AudioBufferSourceNode {
             };
             let (pr_param, pr_proc) = context
                 .base()
-                .create_audio_param(playback_rate_param_options, registration.id());
+                .create_audio_param(playback_rate_param_options, &registration);
 
             pr_param.set_value(playback_rate);
 
