@@ -108,11 +108,11 @@ impl AudioNode for DelayNode {
         &self.channel_config
     }
 
-    fn number_of_inputs(&self) -> u32 {
+    fn number_of_inputs(&self) -> usize {
         1
     }
 
-    fn number_of_outputs(&self) -> u32 {
+    fn number_of_outputs(&self) -> usize {
         1
     }
 
@@ -120,8 +120,8 @@ impl AudioNode for DelayNode {
     fn connect_at<'a>(
         &self,
         dest: &'a dyn AudioNode,
-        output: u32,
-        input: u32,
+        output: usize,
+        input: usize,
     ) -> &'a dyn AudioNode {
         if self.context() != dest.context() {
             panic!("InvalidAccessError: Attempting to connect nodes from different contexts");
@@ -133,8 +133,12 @@ impl AudioNode for DelayNode {
             panic!("IndexSizeError: input port {} is out of bounds", input);
         }
 
-        self.context()
-            .connect(self.reader_registration.id(), dest.id(), output, input);
+        self.context().connect(
+            self.reader_registration.id(),
+            dest.registration().id(),
+            output,
+            input,
+        );
 
         dest
     }
@@ -146,7 +150,7 @@ impl AudioNode for DelayNode {
         }
 
         self.context()
-            .disconnect_from(self.reader_registration.id(), dest.id());
+            .disconnect_from(self.reader_registration.id(), dest.registration().id());
 
         dest
     }
@@ -210,7 +214,7 @@ impl DelayNode {
                 };
                 let (param, proc) = context
                     .base()
-                    .create_audio_param(param_opts, reader_registration.id());
+                    .create_audio_param(param_opts, &reader_registration);
 
                 param.set_value_at_time(options.delay_time as f32, 0.);
 
