@@ -138,12 +138,12 @@ impl AudioNode for OscillatorNode {
     }
 
     /// `OscillatorNode` is a source node. A source node is by definition with no input
-    fn number_of_inputs(&self) -> u32 {
+    fn number_of_inputs(&self) -> usize {
         0
     }
 
     /// `OscillatorNode` is a mono source node.
-    fn number_of_outputs(&self) -> u32 {
+    fn number_of_outputs(&self) -> usize {
         1
     }
 }
@@ -197,7 +197,7 @@ impl OscillatorNode {
             };
             let (f_param, f_proc) = context
                 .base()
-                .create_audio_param(freq_param_opts, registration.id());
+                .create_audio_param(freq_param_opts, &registration);
             f_param.set_value(frequency);
 
             // detune audio parameter
@@ -209,7 +209,7 @@ impl OscillatorNode {
             };
             let (det_param, det_proc) = context
                 .base()
-                .create_audio_param(det_param_opts, registration.id());
+                .create_audio_param(det_param_opts, &registration);
             det_param.set_value(detune);
 
             let type_ = Arc::new(AtomicU32::new(type_ as u32));
