@@ -156,11 +156,11 @@ impl AudioNode for PannerNode {
         &self.channel_config
     }
 
-    fn number_of_inputs(&self) -> u32 {
+    fn number_of_inputs(&self) -> usize {
         1 + 9 // todo, user should not be able to see these ports
     }
 
-    fn number_of_outputs(&self) -> u32 {
+    fn number_of_outputs(&self) -> usize {
         1
     }
 
@@ -182,13 +182,14 @@ impl AudioNode for PannerNode {
 impl PannerNode {
     pub fn new<C: BaseAudioContext>(context: &C, options: PannerOptions) -> Self {
         let node = context.base().register(move |registration| {
-            let id = registration.id();
-
             use crate::spatial::PARAM_OPTS;
             // position params
-            let (position_x, render_px) = context.base().create_audio_param(PARAM_OPTS, id);
-            let (position_y, render_py) = context.base().create_audio_param(PARAM_OPTS, id);
-            let (position_z, render_pz) = context.base().create_audio_param(PARAM_OPTS, id);
+            let (position_x, render_px) =
+                context.base().create_audio_param(PARAM_OPTS, &registration);
+            let (position_y, render_py) =
+                context.base().create_audio_param(PARAM_OPTS, &registration);
+            let (position_z, render_pz) =
+                context.base().create_audio_param(PARAM_OPTS, &registration);
             position_x.set_value_at_time(options.position_x, 0.);
             position_y.set_value_at_time(options.position_y, 0.);
             position_z.set_value_at_time(options.position_z, 0.);
@@ -198,10 +199,13 @@ impl PannerNode {
                 default_value: 1.0,
                 ..PARAM_OPTS
             };
-            let (orientation_x, render_ox) =
-                context.base().create_audio_param(orientation_x_opts, id);
-            let (orientation_y, render_oy) = context.base().create_audio_param(PARAM_OPTS, id);
-            let (orientation_z, render_oz) = context.base().create_audio_param(PARAM_OPTS, id);
+            let (orientation_x, render_ox) = context
+                .base()
+                .create_audio_param(orientation_x_opts, &registration);
+            let (orientation_y, render_oy) =
+                context.base().create_audio_param(PARAM_OPTS, &registration);
+            let (orientation_z, render_oz) =
+                context.base().create_audio_param(PARAM_OPTS, &registration);
             orientation_x.set_value_at_time(options.orientation_x, 0.);
             orientation_y.set_value_at_time(options.orientation_y, 0.);
             orientation_z.set_value_at_time(options.orientation_z, 0.);
@@ -249,7 +253,9 @@ impl PannerNode {
         });
 
         // after the node is registered, connect the AudioListener
-        context.base().connect_listener_to_panner(node.id());
+        context
+            .base()
+            .connect_listener_to_panner(node.registration().id());
 
         node
     }
