@@ -65,11 +65,11 @@ impl AudioNode for StereoPannerNode {
         &self.channel_config
     }
 
-    fn number_of_inputs(&self) -> u32 {
+    fn number_of_inputs(&self) -> usize {
         1
     }
 
-    fn number_of_outputs(&self) -> u32 {
+    fn number_of_outputs(&self) -> usize {
         1
     }
 
@@ -127,7 +127,7 @@ impl StereoPannerNode {
             };
             let (pan_param, pan_proc) = context
                 .base()
-                .create_audio_param(pan_param_opts, registration.id());
+                .create_audio_param(pan_param_opts, &registration);
 
             pan_param.set_value(pan_value);
 
